// Pickin' Sticks Arcade, Rachel J. Morris 2012
// https://github.com/Moosader/Pickin-Sticks-Arcade
// www.moosader.com
// Licensed TBD!

package com.moosader.entities;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.Input.Keys;
import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.graphics.Texture.TextureFilter;
import com.badlogic.gdx.graphics.g2d.Sprite;
import com.badlogic.gdx.graphics.g2d.TextureRegion;
import com.badlogic.gdx.math.Vector2;

// Polling: http://code.google.com/p/libgdx/wiki/InputPolling
// Event: http://code.google.com/p/libgdx/wiki/InputEvent

public class Player extends EntityBase {

	private float m_frame;
	private float m_maxFrame;
	private float m_direction;
	private int m_score;
	float m_speed;
	
	public Player() { setup(); }
	
	public void setup()
	{
		// ToDo: Make prettier
		m_speed = 1.0f;
		m_coord = new Vector2(128f, 128f);
		m_dimen = new Vector2(32f, 32f);
		
		m_direction = 0;
		m_frame = 0;
		m_maxFrame = 2;
		
		m_texture = new Texture(Gdx.files.internal("data/gfx/wipplayer.png"));
		m_texture.setFilter(TextureFilter.Linear, TextureFilter.Linear);
		
		m_region = new TextureRegion(m_texture, 0, 0, 128, 128);
		
		m_sprite = new Sprite(m_region);
		m_sprite.setPosition(m_coord.x, m_coord.y);
		m_sprite.setSize(m_dimen.x, m_dimen.y);
	}
	
	// TODO: Fix how physics work
	public void update(float delta) {
		updateFrame();
	}
	
	public void handleInput(Sprite dpad){
		// ToDo: Create Input/Controls class with customization
		float movedX = -1, movedY = -1;
		
		if ( buttonMoveLeftPressed(dpad) )
		{
			m_direction = 2;
			movedX = m_coord.x - m_speed;
		}
		else if (buttonMoveRightPressed(dpad) )
		{
			m_direction = 3;
			movedX = m_coord.x + m_speed;
		}
		
		if (buttonMoveUpPressed(dpad) )
		{
			m_direction = 1;
			movedY = m_coord.y + m_speed;
		}
		else if (buttonMoveDownPressed(dpad) )
		{
			m_direction = 0;
			movedY = m_coord.y - m_speed;
		}		
		
		// Don't let off the side of the screen
		if ( movedX > 0 && movedX < (320-m_dimen.x)) {
			m_coord.x = movedX;
		}
		
		if ( movedY > 0 && movedY < (320-m_dimen.y)) {
			m_coord.y = movedY;
		}
		
		if ( movedX != -1 || movedY != -1 ) {
			m_frame = m_frame += 0.1f;
			if ( m_frame >= m_maxFrame ) {
				m_frame = 0;
			}
		}
	}
	
	public int getScore() { return m_score; }
	public void incrementScore() { m_score++; }
	
	public void updateFrame()
	{	
		// Update region based on Frame / Direction
		// setRegion: width, height, x, y
		m_region.setRegion(
				(int)((int)(m_frame)*128), 
				(int)((int)(m_direction) *128),
				128, 128);
		
		m_sprite.setPosition(m_coord.x, m_coord.y);
		m_sprite.setRegion(m_region);
	}
	
	private boolean buttonMoveLeftPressed(Sprite dpad) {
		if ( Gdx.input.isKeyPressed(Keys.DPAD_LEFT) ||
				Gdx.input.isKeyPressed(Keys.A) ) {
			return true;
		}
		
		if ( Gdx.input.isTouched() ) {
			float x = Gdx.input.getX();
			float y = Gdx.graphics.getHeight() - Gdx.input.getY();
			
			if ( x < dpad.getX() + dpad.getWidth() / 2 &&
					x > dpad.getX() &&
					y < dpad.getY() + 2 * dpad.getHeight() / 3 &&
					y > dpad.getY() + dpad.getHeight() / 3 )
			{
				return true;
			}
		}
		return false;
	}
	
	private boolean buttonMoveRightPressed(Sprite dpad) {
		if (Gdx.input.isKeyPressed(Keys.DPAD_RIGHT) ||
				Gdx.input.isKeyPressed(Keys.D)){
			return true;
		}
		
		if ( Gdx.input.isTouched() ) {
			float x = Gdx.input.getX();
			float y = Gdx.graphics.getHeight() - Gdx.input.getY();
			
			if ( x < dpad.getX() + dpad.getWidth() &&
					x > dpad.getX() + dpad.getWidth() / 2 &&
					y < dpad.getY() + 2 * dpad.getHeight() / 3 &&
					y > dpad.getY() + dpad.getHeight() / 3 )
			{
				return true;
			}
		}
		return false;
	}
	
	private boolean buttonMoveUpPressed(Sprite dpad) {
		if (Gdx.input.isKeyPressed(Keys.DPAD_UP) ||
				Gdx.input.isKeyPressed(Keys.W) ){
					return true;
				}
		
		if ( Gdx.input.isTouched() ) {
			float x = Gdx.input.getX();
			float y = Gdx.graphics.getHeight() - Gdx.input.getY();
			
			if ( x < dpad.getX() + 2 * dpad.getHeight() / 3 &&
					x > dpad.getX() + dpad.getHeight() / 3 &&
					y < dpad.getY() + dpad.getHeight() &&
					y > dpad.getY() + dpad.getHeight() / 2 )
			{
				return true;
			}
		}
		return false;
	}
	
	private boolean buttonMoveDownPressed(Sprite dpad) {
		if (Gdx.input.isKeyPressed(Keys.DPAD_DOWN) ||
				Gdx.input.isKeyPressed(Keys.S) ){
					return true;
				}
		
		if ( Gdx.input.isTouched() ) {
			float x = Gdx.input.getX();
			float y = Gdx.graphics.getHeight() - Gdx.input.getY();
			
			if ( x < dpad.getX() + 2 * dpad.getWidth() / 3 &&
					x > dpad.getX() + dpad.getWidth() / 3 &&
					y < dpad.getY() + dpad.getHeight() / 2 &&
					y > dpad.getY() )
			{
				return true;
			}
		}
		return false;
	}
}
