package com.moosader.screens;

import java.util.ArrayList;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.graphics.Texture.TextureFilter;
import com.badlogic.gdx.graphics.g2d.Sprite;
import com.badlogic.gdx.graphics.g2d.SpriteBatch;
import com.badlogic.gdx.graphics.g2d.TextureRegion;
import com.badlogic.gdx.math.Vector2;

// This is meant to allow sub-screens in the game.
// Screen will be square-shaped, and placed based on the orientation of
// the Android screen.  The game screen will be drawn within the constraints
// of this Screen, while things like the on-screen D-pad are drawn outside.
public class GameScreen {
	private Vector2 m_screenCoord;
	private Vector2 m_screenDimen;
	private float m_tileWH;
	
	protected ArrayList<Sprite> m_lstSprites; 
	
	// ToDo: Put elseware
	private Texture m_buttonTexture;
	
	// Temp public
	public Sprite m_spriteDPad;
	public Sprite m_spriteButton1;
	public Sprite m_spriteButton2;
	
	public GameScreen() {
		m_lstSprites = new ArrayList<Sprite>();
		m_screenDimen = new Vector2();
		m_screenCoord = new Vector2();
		
		m_buttonTexture = new Texture(Gdx.files.internal("data/gfx/wipbuttons.png"));
		m_buttonTexture.setFilter(TextureFilter.Linear, TextureFilter.Linear);
		
		m_spriteDPad = new Sprite(new TextureRegion(m_buttonTexture, 0, 0, 128, 128));
		m_spriteButton1 = new Sprite(new TextureRegion(m_buttonTexture, 128, 0, 128, 128));
		m_spriteButton2 = new Sprite(new TextureRegion(m_buttonTexture, 256, 0, 128, 128));	
		
		resize();
	}

	public void resize() {
		float w = Gdx.graphics.getWidth();
		float h = Gdx.graphics.getHeight();
		
		System.out.println( "Window Res: " + w + ", " + h );
		
		float marginSize;
		
		boolean portrait = false;
		
		if ( w > h ) {
			// GameGear (Landscape) style
			m_screenDimen.x = m_screenDimen.y = h;
			
			marginSize = (w - m_screenDimen.x) / 2;
			m_screenCoord.x = marginSize;
			m_screenCoord.y = 0;
			
			portrait = false;
		} else {
			// GameBoy (Portrait) style
			m_screenDimen.x = m_screenDimen.y = w;
			
			marginSize = Gdx.graphics.getHeight() - m_screenDimen.y;
			m_screenCoord.x = 0;
			m_screenCoord.y = marginSize;
			
			portrait = true;
		}
		
		if ( portrait ) {
			m_spriteDPad.setSize(marginSize/2, marginSize/2);
			m_spriteButton1.setSize(marginSize/2, marginSize/2);
			m_spriteButton2.setSize(marginSize/2, marginSize/2);
			
			m_spriteDPad.setPosition(0, marginSize/2 - m_spriteDPad.getHeight()/2);
			m_spriteButton1.setPosition(w - m_spriteButton1.getWidth()*1.7f, marginSize/2 - m_spriteButton1.getHeight()/2);
			m_spriteButton2.setPosition(w - m_spriteButton2.getWidth(), marginSize/2 - m_spriteButton2.getHeight()/2);			
		} else {
			m_spriteDPad.setSize(marginSize, marginSize);
			m_spriteButton1.setSize(marginSize, marginSize);
			m_spriteButton2.setSize(marginSize, marginSize);
			
			m_spriteDPad.setPosition(0, h/2 - m_spriteDPad.getHeight()/2);
			m_spriteButton1.setPosition(w - marginSize, h/4);
			m_spriteButton2.setPosition(w - marginSize, 2*h/4);
		}
		
		m_tileWH = m_screenDimen.x / 10;
	}
	
	public void drawSprites(SpriteBatch batch) {
		for (Sprite s : m_lstSprites)
		{
			s.draw(batch);
		}

		m_spriteDPad.draw(batch);
		m_spriteButton1.draw(batch);
		m_spriteButton2.draw(batch);

		// clear the sprite list
		m_lstSprites.clear();
	}
	
	public void addSprite(Sprite spr) {
		Sprite adjustedSprite = new Sprite(spr);
		
		// Adjust sprite position/dimensions to fit into the screen constraints.
		float horizRatio = spr.getX() / spr.getWidth();//Gdx.graphics.getWidth();
		float vertRatio = spr.getY() / spr.getHeight();//Gdx.graphics.getHeight();
		
		//adjustedSprite.setPosition(horizRatio * m_screenDimen.x, vertRatio * m_screenDimen.y);
		adjustedSprite.setPosition(horizRatio * m_tileWH + m_screenCoord.x, vertRatio * m_tileWH + m_screenCoord.y);
		adjustedSprite.setSize(m_tileWH, m_tileWH);
		
		m_lstSprites.add(adjustedSprite);
	}
}
