// Pickin' Sticks Arcade, Rachel J. Morris 2012
// https://github.com/Moosader/Pickin-Sticks-Arcade
// www.moosader.com
// Licensed TBD!

package com.moosader.states;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.graphics.GL10;
import com.badlogic.gdx.graphics.OrthographicCamera;
import com.badlogic.gdx.graphics.g2d.BitmapFont;
import com.badlogic.gdx.graphics.g2d.SpriteBatch;
import com.moosader.entities.EntityBase;
import com.moosader.entities.Item;
import com.moosader.entities.Map;
import com.moosader.entities.Player;
import com.moosader.screens.GameScreen;

// This is the game state for Pickin' Sticks Classic--
// The really simple old game where all you do is pick up sticks endlessly
public class ClassicGameState extends BaseState {	
	private OrthographicCamera m_camera;
	private SpriteBatch m_batch;
	
	private GameScreen m_gameScreen;
	
	// ToDo: Manager Class
	private Player m_player;
	private Item m_item;
	private Map m_map;
	
	// ToDo: put elseware
	private BitmapFont m_font;
	private CharSequence m_scoreData;
	
	public ClassicGameState() { setup(); }
	
	public void setup() {
		m_isDone = false;
		float w = Gdx.graphics.getWidth();
		float h = Gdx.graphics.getHeight();
		
		m_camera = new OrthographicCamera();
		m_camera.setToOrtho(false, w, h);
		
		m_gameScreen = new GameScreen();
		
		m_batch = new SpriteBatch(); 

		// All this should be handld elseware
		m_map = new Map();
		m_player = new Player();
		m_item = new Item();
		
		m_font = new BitmapFont(Gdx.files.internal("data/fonts/Averia.fnt"), 
				Gdx.files.internal("data/fonts/Averia.png"), false);
	}
	
	private boolean isCollision(EntityBase obj1, EntityBase obj2) {
		if ( obj1.getLeft() < obj2.getRight() &&
				obj1.getRight() > obj2.getLeft() &&
				obj1.getTop() > obj2.getBottom() &&
				obj1.getBottom() < obj2.getTop() )
		{
			return true;
		}
		return false;
	}
	
	public void dispose() {
		m_batch.dispose();
	}
	
	@Override
	public void resize(int width, int height){
		// Update the screen positioning!
		System.out.println( "Resize!" );
		m_gameScreen.resize();
	}

	@Override
	public void update(float delta) {
		// Update entities, get input
		m_player.handleInput(m_gameScreen.m_spriteDPad);
		m_player.update(delta);
		m_item.update(delta);
		
		
		if ( isCollision(m_player, m_item) ) {
			m_item.generateNewCoordinates();
			m_player.incrementScore();
		}

		m_scoreData = "Score:" + Integer.toString(m_player.getScore());
		
		// Populate the sprite list
		m_map.pushTiles(m_gameScreen);
		m_gameScreen.addSprite(m_player.m_sprite);	
		m_gameScreen.addSprite(m_item.m_sprite);		
		m_camera.update();
	}

	@Override
	public void draw(float delta) {		
		Gdx.gl.glClearColor(0.2f, 0.2f, 0.2f, 1);
		Gdx.gl.glClear(GL10.GL_COLOR_BUFFER_BIT);
		
		m_batch.setProjectionMatrix(m_camera.combined);
		m_batch.begin();
		
		m_gameScreen.drawSprites(m_batch);
		
		m_font.setColor( 1.0f, 1.0f, 1.0f, 1.0f );
		m_font.draw(m_batch, m_scoreData, 25, Gdx.graphics.getHeight() - 14);
		
		m_batch.end();	
	}

	@Override
	public boolean isDone() {
		return false;
	}

}
